==> zio-aws-accessanalyzer_2.13-6.20.74.2-sources.jar: zio/aws/accessanalyzer/model/FindingSourceDetail.scala <==
package zio.aws.accessanalyzer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class FindingSourceDetail(
    accessPointArn: Optional[String] = Optional.Absent,
    accessPointAccount: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.accessanalyzer.model.FindingSourceDetail = {
    import FindingSourceDetail.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.accessanalyzer.model.FindingSourceDetail
      .builder()
      .optionallyWith(accessPointArn.map(value => value: java.lang.String))(
        _.accessPointArn
      )
      .optionallyWith(accessPointAccount.map(value => value: java.lang.String))(
        _.accessPointAccount
      )
      .build()
  }
  def asReadOnly: zio.aws.accessanalyzer.model.FindingSourceDetail.ReadOnly =
    zio.aws.accessanalyzer.model.FindingSourceDetail.wrap(buildAwsValue())
}
object FindingSourceDetail {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.accessanalyzer.model.FindingSourceDetail
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.accessanalyzer.model.FindingSourceDetail =
      zio.aws.accessanalyzer.model.FindingSourceDetail(
        accessPointArn.map(value => value),
        accessPointAccount.map(value => value)
      )
    def accessPointArn: Optional[String]
    def accessPointAccount: Optional[String]
    def getAccessPointArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("accessPointArn", accessPointArn)
    def getAccessPointAccount: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("accessPointAccount", accessPointAccount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.accessanalyzer.model.FindingSourceDetail
  ) extends zio.aws.accessanalyzer.model.FindingSourceDetail.ReadOnly {
    override val accessPointArn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.accessPointArn())
      .map(value => value: String)
    override val accessPointAccount: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.accessPointAccount())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.accessanalyzer.model.FindingSourceDetail
  ): zio.aws.accessanalyzer.model.FindingSourceDetail.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-accessanalyzer_3-5.17.104.1-sources.jar: zio/aws/accessanalyzer/model/FindingSourceDetail.scala <==
package zio.aws.accessanalyzer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class FindingSourceDetail(accessPointArn: Option[String] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.accessanalyzer.model.FindingSourceDetail = {
    import FindingSourceDetail.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.accessanalyzer.model.FindingSourceDetail
      .builder()
      .optionallyWith(accessPointArn.map(value => value: java.lang.String))(
        _.accessPointArn
      )
      .build()
  }
  def asReadOnly: zio.aws.accessanalyzer.model.FindingSourceDetail.ReadOnly =
    zio.aws.accessanalyzer.model.FindingSourceDetail.wrap(buildAwsValue())
}
object FindingSourceDetail {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.accessanalyzer.model.FindingSourceDetail
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.accessanalyzer.model.FindingSourceDetail =
      zio.aws.accessanalyzer.model
        .FindingSourceDetail(accessPointArn.map(value => value))
    def accessPointArn: Option[String]
    def getAccessPointArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("accessPointArn", accessPointArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.accessanalyzer.model.FindingSourceDetail
  ) extends zio.aws.accessanalyzer.model.FindingSourceDetail.ReadOnly {
    override val accessPointArn: Option[String] =
      scala.Option(impl.accessPointArn()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.accessanalyzer.model.FindingSourceDetail
  ): zio.aws.accessanalyzer.model.FindingSourceDetail.ReadOnly = new Wrapper(
    impl
  )
}
